Module blaxel.core.client.models.pending_invitation
===================================================

Classes
-------

`PendingInvitation(created_at: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, updated_at: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, created_by: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, updated_by: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, email: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, invited_by: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, role: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, workspace: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Pending invitation in workspace
    
    Attributes:
        created_at (Union[Unset, str]): The date and time when the resource was created
        updated_at (Union[Unset, str]): The date and time when the resource was updated
        created_by (Union[Unset, str]): The user or service account who created the resource
        updated_by (Union[Unset, str]): The user or service account who updated the resource
        email (Union[Unset, str]): User email
        invited_by (Union[Unset, str]): User sub
        role (Union[Unset, str]): ACL role
        workspace (Union[Unset, str]): Workspace name
    
    Method generated by attrs for class PendingInvitation.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `created_at: blaxel.core.client.types.Unset | str`
    :

    `created_by: blaxel.core.client.types.Unset | str`
    :

    `email: blaxel.core.client.types.Unset | str`
    :

    `invited_by: blaxel.core.client.types.Unset | str`
    :

    `role: blaxel.core.client.types.Unset | str`
    :

    `updated_at: blaxel.core.client.types.Unset | str`
    :

    `updated_by: blaxel.core.client.types.Unset | str`
    :

    `workspace: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :